#!/usr/bin/env bash
#
# Waits until cert-manager HelmRelease is ready, and then installs a ZeroSSL
# ClusterIssuer with our credentials into the cert-manager namespace
#
# Usage:
#
#   ./install_zerossl_issuer.sh
set -euo pipefail

# Create secret with HMAC key
b64tlskey=$(echo -n "${ZEROSSL_TLS_KEY}" | base64 -w0)

# Wait until cert-manager is ready
"$(dirname "$0")/retry_cmd_until_success.sh" 30 10 "flux get kustomization --status-selector ready=true --no-header | grep '^cert-manager'"

# Add ZeroSSL ClusterIssuer
kubectl apply -n cert-manager -f - <<EOF
---
apiVersion: v1
kind: Secret
metadata:
  namespace: cert-manager
  name: zerossl-prod
data:
  tls.key: ${b64tlskey}
---
apiVersion: cert-manager.io/v1
kind: ClusterIssuer
metadata:
  name: zerossl-issuer
spec:
  acme:
    # The ACME server URL
    server: https://acme.zerossl.com/v2/DV90
    disableAccountKeyGeneration: true
    # Name of the secret used to get the ACME account private key
    privateKeySecretRef:
      name: zerossl-prod
    solvers:
      - http01:
          ingress:
            class: nginx
EOF
